This is an automated email from the ASF dual-hosted git repository.

elecharny pushed a commit to branch 1.2.X
in repository https://gitbox.apache.org/repos/asf/mina-ftpserver.git


The following commit(s) were added to refs/heads/1.2.X by this push:
     new 583db0b7 Minor code refactoring for clarity
583db0b7 is described below

commit 583db0b774fb72383cb24bb88a2cfd8f8f51b008
Author: emmanuel lecharny <[email protected]>
AuthorDate: Tue Jan 7 10:15:22 2025 +0100

    Minor code refactoring for clarity
---
 .../apache/ftpserver/ftplet/Authentication.java    |  1 -
 .../ftplet/AuthenticationFailedException.java      |  9 +++-----
 .../org/apache/ftpserver/ftplet/Authority.java     |  7 ++----
 .../ftpserver/ftplet/AuthorizationRequest.java     |  1 -
 .../apache/ftpserver/ftplet/DataConnection.java    | 19 +++++++--------
 .../ftpserver/ftplet/DataConnectionFactory.java    |  2 --
 .../ftpserver/ftplet/DataTransferFtpReply.java     |  1 -
 .../java/org/apache/ftpserver/ftplet/DataType.java | 23 ++++++++----------
 .../apache/ftpserver/ftplet/DefaultFtpReply.java   | 27 ++++++++++++----------
 .../ftpserver/ftplet/FileActionFtpReply.java       |  2 --
 .../org/apache/ftpserver/ftplet/FtpException.java  | 13 ++++-------
 .../java/org/apache/ftpserver/ftplet/FtpReply.java |  2 +-
 .../org/apache/ftpserver/ftplet/FtpRequest.java    |  4 +++-
 .../org/apache/ftpserver/ftplet/FtpStatistics.java | 23 ++++++++++++++----
 .../java/org/apache/ftpserver/ftplet/Ftplet.java   | 10 ++++----
 .../org/apache/ftpserver/ftplet/FtpletContext.java |  5 +++-
 .../org/apache/ftpserver/ftplet/FtpletResult.java  |  1 -
 .../apache/ftpserver/ftplet/RenameFtpReply.java    |  2 --
 .../org/apache/ftpserver/ftplet/Structure.java     | 18 +++++++--------
 19 files changed, 82 insertions(+), 88 deletions(-)

diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Authentication.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Authentication.java
index 296551a3..44edaf5f 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Authentication.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Authentication.java
@@ -26,5 +26,4 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public interface Authentication {
-
 }
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/AuthenticationFailedException.java
 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/AuthenticationFailedException.java
index 06b44406..dfae8f15 100644
--- 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/AuthenticationFailedException.java
+++ 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/AuthenticationFailedException.java
@@ -38,8 +38,7 @@ public class AuthenticationFailedException extends 
FtpException {
      * Constructs a <code>AuthenticationFailedException</code> object with a
      * message.
      *
-     * @param msg
-     *            A description of the exception
+     * @param msg A description of the exception
      */
     public AuthenticationFailedException(String msg) {
         super(msg);
@@ -49,8 +48,7 @@ public class AuthenticationFailedException extends 
FtpException {
      * Constructs a <code>AuthenticationFailedException</code> object with a
      * <code>Throwable</code> cause.
      *
-     * @param th
-     *            The original cause
+     * @param th The original cause
      */
     public AuthenticationFailedException(Throwable th) {
         super(th);
@@ -61,8 +59,7 @@ public class AuthenticationFailedException extends 
FtpException {
      * <code>Throwable</code> cause.
      * @param msg A description of the exception
      *
-     * @param th
-     *            The original cause
+     * @param th The original cause
      */
     public AuthenticationFailedException(String msg, Throwable th) {
         super(msg, th);
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Authority.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Authority.java
index ea111aba..0e7ffe96 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Authority.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Authority.java
@@ -26,12 +26,10 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public interface Authority {
-
     /**
      * Indicates weather this Authority can authorize a certain request
      *
-     * @param request
-     *            The request to authorize
+     * @param request The request to authorize
      * @return True if the request can be authorized by this Authority
      */
     boolean canAuthorize(AuthorizationRequest request);
@@ -39,8 +37,7 @@ public interface Authority {
     /**
      * Authorize an {@link AuthorizationRequest}.
      *
-     * @param request
-     *            The {@link AuthorizationRequest}
+     * @param request The {@link AuthorizationRequest}
      * @return Returns a populated AuthorizationRequest as long as If
      *         {@link #canAuthorize(AuthorizationRequest)} returns 
<code>true</code> for the
      *         AuthorizationRequest, otherwise returns <code>null</code>.
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/AuthorizationRequest.java
 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/AuthorizationRequest.java
index e99d47a1..d6e2fd8b 100644
--- 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/AuthorizationRequest.java
+++ 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/AuthorizationRequest.java
@@ -25,5 +25,4 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public interface AuthorizationRequest {
-
 }
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataConnection.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataConnection.java
index 39222a14..0675edd3 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataConnection.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataConnection.java
@@ -29,35 +29,32 @@ import java.io.OutputStream;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public interface DataConnection {
-
     /**
      * Transfer data from the client (e.g. STOR).
+     *
      * @param session The current {@link FtpSession}
-     * @param out
-     *            The {@link OutputStream} containing the destination of the
+     * @param out The {@link OutputStream} containing the destination of the
      *            data from the client.
      * @return The length of the transferred data
      * @throws IOException If the transfer failed
      */
-    long transferFromClient(FtpSession session, OutputStream out)
-            throws IOException;
+    long transferFromClient(FtpSession session, OutputStream out) throws 
IOException;
 
     /**
      * Transfer data to the client (e.g. RETR).
+     *
      * @param session The current {@link FtpSession}
-     * @param in
-     *            Data to be transfered to the client
+     * @param in Data to be transfered to the client
      * @return The length of the transferred data
      * @throws IOException If the transfer failed
      */
-    long transferToClient(FtpSession session, InputStream in)
-            throws IOException;
+    long transferToClient(FtpSession session, InputStream in) throws 
IOException;
 
     /**
      * Transfer a string to the client, e.g. during LIST
+     *
      * @param session The current {@link FtpSession}
-     * @param str
-     *            The string to transfer
+     * @param str The string to transfer
      * @throws IOException If the transfer failed
      */
     void transferToClient(FtpSession session, String str) throws IOException;
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataConnectionFactory.java
 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataConnectionFactory.java
index 7accfc2c..b4869418 100644
--- 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataConnectionFactory.java
+++ 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataConnectionFactory.java
@@ -25,7 +25,6 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public interface DataConnectionFactory {
-
     /**
      * Open an active data connection
      *
@@ -40,7 +39,6 @@ public interface DataConnectionFactory {
      *
      * @return <code>true</code> if the data socket will be secured
      */
-
     boolean isSecure();
 
     /**
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataTransferFtpReply.java
 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataTransferFtpReply.java
index 38127333..71b3a025 100644
--- 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataTransferFtpReply.java
+++ 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataTransferFtpReply.java
@@ -25,7 +25,6 @@ package org.apache.ftpserver.ftplet;
  * etc.
  *
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
- *
  */
 
 public interface DataTransferFtpReply extends FileActionFtpReply {
diff --git a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataType.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataType.java
index 4d09b60e..7b7e9950 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataType.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DataType.java
@@ -25,7 +25,6 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public enum DataType {
-
     /**
      * Binary data type
      */
@@ -39,22 +38,20 @@ public enum DataType {
     /**
      * Parses the argument value from the TYPE command into the type safe class
      *
-     * @param argument
-     *            The argument value from the TYPE command. Not case sensitive
+     * @param argument The argument value from the TYPE command. Not case 
sensitive
      * @return The appropriate data type
-     * @throws IllegalArgumentException
-     *             If the data type is unknown
+     * @throws IllegalArgumentException If the data type is unknown
      */
     public static DataType parseArgument(char argument) {
         switch (argument) {
-        case 'A':
-        case 'a':
-            return ASCII;
-        case 'I':
-        case 'i':
-            return BINARY;
-        default:
-            throw new IllegalArgumentException("Unknown data type: " + 
argument);
+            case 'A':
+            case 'a':
+                return ASCII;
+            case 'I':
+            case 'i':
+                return BINARY;
+            default:
+                throw new IllegalArgumentException("Unknown data type: " + 
argument);
         }
     }
 }
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FileActionFtpReply.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FileActionFtpReply.java
index 3343d4b9..cf022f79 100644
--- 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FileActionFtpReply.java
+++ 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FileActionFtpReply.java
@@ -24,11 +24,9 @@ package org.apache.ftpserver.ftplet;
  * single file or directory such as MKD, DELE, RMD etc.
  *
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
- *
  */
 
 public interface FileActionFtpReply extends FtpReply {
-
     /**
      * Returns the file (or directory) on which the action was taken
      * (e.g. uploaded, created, listed)
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpException.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpException.java
index d82b7fd3..bf227111 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpException.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpException.java
@@ -26,7 +26,6 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public class FtpException extends Exception {
-
     private static final long serialVersionUID = -1328383839915898987L;
 
     /**
@@ -39,8 +38,7 @@ public class FtpException extends Exception {
     /**
      * Constructs a <code>FtpException</code> object with a message.
      *
-     * @param msg
-     *            a description of the exception
+     * @param msg a description of the exception
      */
     public FtpException(String msg) {
         super(msg);
@@ -50,8 +48,7 @@ public class FtpException extends Exception {
      * Constructs a <code>FtpException</code> object with a
      * <code>Throwable</code> cause.
      *
-     * @param th
-     *            the original cause
+     * @param th the original cause
      */
     public FtpException(Throwable th) {
         super(th.getMessage());
@@ -60,10 +57,9 @@ public class FtpException extends Exception {
     /**
      * Constructs a <code>BaseException</code> object with a
      * <code>Throwable</code> cause.
-     * @param msg A description of the exception
      *
-     * @param th
-     *            The original cause
+     * @param msg A description of the exception
+     * @param th The original cause
      */
     public FtpException(String msg, Throwable th) {
         super(msg);
@@ -71,6 +67,7 @@ public class FtpException extends Exception {
 
     /**
      * Get the root cause.
+     *
      * @return The root cause
      * @deprecated Use {@link Exception#getCause()} instead
      */
diff --git a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpReply.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpReply.java
index 921543d4..d3916e95 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpReply.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpReply.java
@@ -25,7 +25,6 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public interface FtpReply {
-
     /**
      * 110 Restart marker reply. In this case, the text is exact and not left 
to
      * the particular implementation; it must read: MARK yyyy = mmmm Where yyyy
@@ -264,6 +263,7 @@ public interface FtpReply {
 
     /**
      * Tells whether or not this reply indicates a positive completion.
+     *
      * @return <code>true</code>, if this reply is a positive completion or
      * positive intermediate reply; <code>false</code>, otherwise.
      */
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpRequest.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpRequest.java
index fa617acb..07be2114 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpRequest.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpRequest.java
@@ -25,21 +25,23 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public interface FtpRequest {
-
     /**
      * Get the client request string.
+     *
      * @return The full request line, e.g. "MKDIR newdir"
      */
     String getRequestLine();
 
     /**
      * Returns the ftp request command.
+     *
      * @return The command part of the request line, e.g. "MKDIR"
      */
     String getCommand();
 
     /**
      * Get the ftp request argument.
+     *
      * @return The argument part of the request line, e.g. "newdir"
      */
     String getArgument();
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpStatistics.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpStatistics.java
index a446cf2f..6e030d04 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpStatistics.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpStatistics.java
@@ -28,99 +28,114 @@ import java.util.Date;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public interface FtpStatistics {
-
     /**
      * Get the server start time.
+     *
      * @return The {@link Date} when the server started
      */
     Date getStartTime();
 
     /**
      * Get number of files uploaded.
+     *
      * @return The total number of uploads
      */
     int getTotalUploadNumber();
 
     /**
      * Get number of files downloaded.
+     *
      * @return The total number of downloads
      */
     int getTotalDownloadNumber();
 
     /**
      * Get number of files deleted.
+     *
      * @return The total number of deletions
      */
     int getTotalDeleteNumber();
 
     /**
      * Get total number of bytes uploaded.
+     *
      * @return The total number of bytes uploaded
      */
     long getTotalUploadSize();
 
     /**
      * Get total number of bytes downloaded.
+     *
      * @return The total number of bytes downloaded
      */
     long getTotalDownloadSize();
 
     /**
      * Get total directory created.
+     *
      * @return The total number of created directories
      */
     int getTotalDirectoryCreated();
 
     /**
      * Get total directory removed.
+     *
      * @return The total number of removed directories
      */
     int getTotalDirectoryRemoved();
 
     /**
      * Get total number of connections
+     *
      * @return The total number of connections
      */
     int getTotalConnectionNumber();
 
     /**
      * Get current number of connections.
+     *
      * @return The current number of connections
      */
     int getCurrentConnectionNumber();
 
     /**
      * Get total login number.
+     *
      * @return The total number of logins
      */
     int getTotalLoginNumber();
 
     /**
      * Get total failed login number.
+     *
      * @return The total number of failed logins
      */
     int getTotalFailedLoginNumber();
 
     /**
      * Get current login number
+     *
      * @return The current number of logins
      */
     int getCurrentLoginNumber();
 
     /**
      * Get total anonymous login number.
+     *
      * @return The total number of anonymous logins
      */
     int getTotalAnonymousLoginNumber();
 
     /**
      * Get current anonymous login number.
+     *
      * @return The current number of anonymous logins
      */
     int getCurrentAnonymousLoginNumber();
 
     /**
      * Get the login number for the specific user
+     *
      * @param user The {@link User} for which to retrieve the number of logins
      * @return The total number of logins for the provided user
      */
@@ -129,10 +144,8 @@ public interface FtpStatistics {
     /**
      * Get the login number for the specific user from the ipAddress
      *
-     * @param user
-     *            login user account
-     * @param ipAddress
-     *            the ip address of the remote user
+     * @param user login user account
+     * @param ipAddress the ip address of the remote user
      * @return The total number of logins for the provided user and IP address
      */
     int getCurrentUserLoginNumber(User user, InetAddress ipAddress);
diff --git a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Ftplet.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Ftplet.java
index 6024254c..6fd5aff8 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Ftplet.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Ftplet.java
@@ -47,12 +47,12 @@ import java.io.IOException;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public interface Ftplet {
-
     /**
      * Called by the ftplet container to indicate to a ftplet that the ftplet 
is
      * being placed into service. The ftplet container calls the init method
      * exactly once after instantiating the ftplet. The init method must
      * complete successfully before the ftplet can receive any requests.
+     *
      * @param ftpletContext The current {@link FtpletContext}
      * @throws FtpException If the initialization failed
      */
@@ -91,8 +91,7 @@ public interface Ftplet {
      * @throws FtpException If a FTP error occurred
      * @throws IOException If an IO error occurred
      */
-    FtpletResult beforeCommand(FtpSession session, FtpRequest request)
-            throws FtpException, IOException;
+    FtpletResult beforeCommand(FtpSession session, FtpRequest request) throws 
FtpException, IOException;
 
     /**
      * Called by the ftplet container after a command has been executed by the
@@ -122,6 +121,7 @@ public interface Ftplet {
 
     /**
      * Client connect notification method.
+     *
      * @param session The current {@link FtpSession}
      * @return The desired action to be performed by the server
      * @throws FtpException If a FTP error occurred
@@ -131,11 +131,11 @@ public interface Ftplet {
 
     /**
      * Client disconnect notification method. This is the last callback method.
+     *
      * @param session The current {@link FtpSession}
      * @return The desired action to be performed by the server
      * @throws FtpException If a FTP error occurred
      * @throws IOException If an IO error occurred
      */
-    FtpletResult onDisconnect(FtpSession session) throws FtpException,
-            IOException;
+    FtpletResult onDisconnect(FtpSession session) throws FtpException, 
IOException;
 }
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpletContext.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpletContext.java
index afe1742b..e6e18f4b 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpletContext.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpletContext.java
@@ -27,27 +27,30 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public interface FtpletContext {
-
     /**
      * Get the user manager.
+     *
      * @return The {@link UserManager}
      */
     UserManager getUserManager();
 
     /**
      * Get file system manager
+     *
      * @return The {@link FileSystemFactory}
      */
     FileSystemFactory getFileSystemManager();
 
     /**
      * Get ftp statistics.
+     *
      * @return The {@link FtpStatistics}
      */
     FtpStatistics getFtpStatistics();
 
     /**
      * Get Ftplet.
+     *
      * @param name The name identifying the {@link Ftplet}
      * @return The {@link Ftplet} registred with the provided name, or null if 
none exists
      */
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpletResult.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpletResult.java
index 60fe1324..e95df6af 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpletResult.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/FtpletResult.java
@@ -27,7 +27,6 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public enum FtpletResult {
-
     /**
      * This return value indicates that the next ftplet method will be called.
      * If no other ftplet is available, the ftpserver will process the request.
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/RenameFtpReply.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/RenameFtpReply.java
index 4e255ae6..ad356152 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/RenameFtpReply.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/RenameFtpReply.java
@@ -26,9 +26,7 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  *
  */
-
 public interface RenameFtpReply extends FtpReply {
-
     /**
      * Returns the file before the rename.
      *
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Structure.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Structure.java
index ce08b7d8..bb4424b7 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Structure.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/Structure.java
@@ -25,7 +25,6 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public enum Structure {
-
     /**
      * File structure
      */
@@ -34,20 +33,19 @@ public enum Structure {
     /**
      * Parses the argument value from the STRU command into the type safe class
      *
-     * @param argument
-     *            The argument value from the STRU command. Not case sensitive
+     * @param argument The argument value from the STRU command. Not case 
sensitive
      * @return The appropriate structure
-     * @throws IllegalArgumentException
-     *             If the structure is unknown
+     * @throws IllegalArgumentException If the structure is unknown
      */
 
     public static Structure parseArgument(char argument) {
         switch (argument) {
-        case 'F':
-        case 'f':
-            return FILE;
-        default:
-            throw new IllegalArgumentException("Unknown structure: " + 
argument);
+            case 'F':
+            case 'f':
+                return FILE;
+
+            default:
+                throw new IllegalArgumentException("Unknown structure: " + 
argument);
         }
     }
 }

Reply via email to
diff --git 
a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DefaultFtpReply.java 
b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DefaultFtpReply.java
index c02603ec..c1007dda 100644
--- a/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DefaultFtpReply.java
+++ b/ftplet-api/src/main/java/org/apache/ftpserver/ftplet/DefaultFtpReply.java
@@ -26,20 +26,20 @@ package org.apache.ftpserver.ftplet;
  * @author <a href="http://mina.apache.org";>Apache MINA Project</a>
  */
 public class DefaultFtpReply implements FtpReply {
-
+    /** The reply code */
     private int code;
 
+    /** The reply message */
     private String message;
 
-    /**
-     * time when this reply was sent.
-     */
+    /** time when this reply was sent. */
     private long sentTime = 0L;
 
     private static final String CRLF = "\r\n";
 
     /**
      * Constructor for single-line messages
+     *
      * @param code The reply code
      * @param message The reply message
      */
@@ -51,17 +51,20 @@ public class DefaultFtpReply implements FtpReply {
 
     /**
      * Constructor for multi-line replies
+     *
      * @param code The reply code
      * @param message The reply message, one line per String
      */
-    public DefaultFtpReply(final int code, final String[] message) {
+    public DefaultFtpReply(final int code, final String[] messageLines) {
         this.code = code;
 
         StringBuilder sb = new StringBuilder();
-        for (int i = 0; i < message.length; i++) {
-            sb.append(message[i]);
+
+        for (String line:messageLines) {
+            sb.append(line);
             sb.append('\n');
         }
+
         this.message = sb.toString();
         this.sentTime = System.currentTimeMillis();
     }
@@ -89,7 +92,7 @@ public class DefaultFtpReply implements FtpReply {
     }
 
     private boolean isDigit(char c) {
-        return c >= 48 && c <= 57;
+        return c >= '0' && c <= '9';
     }
 
     /*
@@ -101,6 +104,7 @@ public class DefaultFtpReply implements FtpReply {
     public String toString() {
         int code = getCode();
         String notNullMessage = getMessage();
+
         if (notNullMessage == null) {
             notNullMessage = "";
         }
@@ -124,7 +128,6 @@ public class DefaultFtpReply implements FtpReply {
             sb.append(notNullMessage);
             sb.append(CRLF);
         } else {
-
             sb.append(code);
             sb.append("-");
 
@@ -143,10 +146,10 @@ public class DefaultFtpReply implements FtpReply {
                         && line.length() > 2
                         && isDigit(line.charAt(0))
                         && isDigit(line.charAt(1))
-                        && isDigit(line.charAt(2))
-                    ) {
+                        && isDigit(line.charAt(2))) {
                     sb.append("  ");
                 }
+
                 sb.append(line);
                 sb.append(CRLF);
             }
@@ -51,17 +51,20 @@ public class DefaultFtpReply implements FtpReply {
      * @param code The reply code
-     * @param message The reply message, one line per String
+     * @param messageLines The reply message, one line per String
      */